@@ -159,30 +159,40 @@ def truncate_database(myuser, mypassword, myhost, database):
         con.commit()
 
 
-def execute_query(myuser, mypassword, myhost, database, cve, score, date):
-    query = "SELECT cve, vector_string_3, base_score_3, base_severity_3, vector_string, base_score, severity, description, published_date FROM cvss WHERE base_score_3 > %s AND date_part('year', published_date) >= %s"
+def execute_query(myuser, mypassword, myhost, database, cve=None, score=None, date=None, out=False):
+    query = "SELECT cve, vector_string_3, base_score_3, base_severity_3, vector_string, base_score, severity, description, published_date FROM cvss WHERE date_part('year', published_date) >= %s"
 
+    args = list()
+    args.append(date)
+
+    if score:
+        query = query + "AND base_score_3 > %s"
+        args.append(score)
     if cve:
         query = query + " AND cve LIKE %s"
+        cve = '%' + cve + '%'
+        args.append(cve)
 
+    selected_cves = list()
 
     with connect(dbname=database, user=myuser, host=myhost, password=mypassword) as con:
         with con.cursor() as cur:
             print("Executing query")
             try:
-                if cve:
-                    cve = '%' + cve + '%'
-                    cur.execute(query, (score, date, cve))
-                else:
-                    cur.execute(query, (score, date))
-                selected_cve = cur.fetchone()
-                answer = ""
-                for r in selected_cve:
-                    if type(r) is str:
-                        answer = answer + r.strip() + "\t"
-                    else:
-                        answer = answer + str(r) + "\t"
-                answer = answer.rstrip('\t')
-                print(answer)
+                cur.execute(query, tuple(args))
+                selected_cves = cur.fetchall()
+
+                if out:
+                    for cve in selected_cves:
+                        answer = ""
+                        for r in cve:
+                            if type(r) is str:
+                                answer = answer + r.strip() + "\t"
+                            else:
+                                answer = answer + str(r) + "\t"
+                        answer = answer.rstrip('\t')
+                        print(answer)
             except(Exception, psycopg2.DatabaseError) as error:
                 print("Error while Querying Database", error)
+
+    return selected_cves
