@@ -21,7 +21,7 @@ def main():
     parser.add_argument('-ct', '--create_tables', action="store_true", dest="ct", default=False, help="Create the tables of the database")
     parser.add_argument('-tr', '--truncate_cves_tables', action="store_true", dest="tr", default=False, help="Truncate the CVEs-related tables")
     parser.add_argument('-cve', '--cvs_number', action="store", dest="cve", default=None, help="Print info for a CVE (CVSS score and other)")
-    parser.add_argument('-sc', '--score', action="store", dest="score", default=-1, help="Use base score of a CVE as a selection criterion")
+    parser.add_argument('-sc', '--score', action="store", dest="score", default=None, help="Use base score of a CVE as a selection criterion")
     parser.add_argument('-dt', '--date', action="store", dest="date", default=-1, help="Use publication date of a CVE as a selection criterion")
     values = parser.parse_args()
 
